@@ -1,9 +1,14 @@
 Coll = function(Formula, Data)
 {
+  Terms = terms(Formula, data=Data)
+  if (!attr(Terms, "response")) stop("Dependent variable should be provided!")
   rx = lm(Formula, Data)
   np = length(rx$coefficients)
 
-  d1 = model.frame(Formula, Data)[,-1]
+  mf = model.frame(Formula, Data)
+  if (!is.numeric(mf[, 1])) stop("Dependent variable should be numeric!")
+
+  d1 = mf[, -1, drop=FALSE]
   Names = colnames(d1)
   nName = NCOL(d1)
   Tol = rep(NA, nName)
@@ -19,16 +24,29 @@ Coll = function(Formula, Data)
 
   Z = scale(model.matrix(Formula, Data), center=FALSE)
   SVDz = svd(Z)
-  p1 = SVDz$v %*% diag(1/SVDz$d)
+  if (length(SVDz$d) == 1) {
+    p1 = SVDz$v %*% diag(1/as.matrix(SVDz$d))
+  } else {
+    p1 = SVDz$v %*% diag(1/SVDz$d)
+  }
+
   p2 = t(p1^2)
-  Res2 = prop.table(p2 %*% diag(rowSums(p2)), 2)
+  if (NCOL(p2) == 1) {
+    Res2 = prop.table(p2 %*% diag(as.matrix(rowSums(p2))), 2)
+  } else {
+    Res2 = prop.table(p2 %*% diag(rowSums(p2)), 2)
+  }
 
   ZpZ = crossprod(Z)
   ev = eigen(ZpZ/diag(ZpZ))$values
   cn = sqrt(ev[1]/ev)
 
   Res2 = cbind(ev, cn, Res2)
-  colnames(Res2) = c("Eigenvalue", "Cond. Index", "(Intercept)", Names)
+  if (attr(Terms, "intercept")) {
+    colnames(Res2) = c("Eigenvalue", "Cond. Index", "(Intercept)", Names)
+  } else {
+    colnames(Res2) = c("Eigenvalue", "Cond. Index", Names)    
+  }
 
   Res = list(Res1, Res2)
   names(Res) = c("Tolerance and VIF", "Collinearity Diagnosis")
